* 株式会社ライトストーン
* Stataではじめるベイズ統計ウェビナー

**# 分析例：感染症の有病率

* データセットの生成
clear
set obs 1
generate byte y = 0

* 有病率の推定
bayesmh y, likelihood(dbinomial({theta}, 20)) ///
           prior({theta}, beta(2, 20)) rseed(16)

* 事後分布の密度プロットを表示
bayesgraph kdensity {theta}

**# bayesプレフィクスコマンド

* サンプルデータの読込み
use https://www.stata-press.com/data/r17/womenwage, clear

* 線形回帰モデル
regress wage age

* 線形回帰モデルのベイズ推定
set seed 15
bayes: regress wage age

* ギブスサンプリング
set seed 15
bayes, gibbs: regress wage age

webuse usmacro, clear
bayes, rseed(17): var inflation ogap fedfunds


**# bayesmhコマンド

* サンプルデータの読込み
use https://www.stata-press.com/data/r17/auto, clear

* 線形回帰モデルのベイズ推定
replace weight = weight/100
set seed 14
bayesmh mpg weight, likelihood(normal({var})) ///
        prior({mpg:}, normal(0,100)) ///
        prior({var}, igamma(10,10)) blocksummary

* 診断プロット
bayesgraph diagnostics {var}

* 散布図行列
bayesgraph matrix _all

* ブロックオプション
set seed 14
bayesmh mpg weight, likelihood(normal({var})) ///
        prior({mpg:}, normal(0,100)) ///
        prior({var}, igamma(10,10)) ///
        block({var}) blocksummary

* 診断プロット
bayesgraph diagnostics {var}

* 複数チェーン
bayesmh mpg weight, likelihood(normal({var})) ///
		prior({mpg:}, normal(0,100)) ///
		prior({var}, igamma(10,10)) ///
		nomodelsummary nchains(4) rseed(16)

* 診断プロット
bayesgraph diagnostics {var}

* Gelman-Rubin 収束診断
bayesstats grubin

